/******************************************************************************
* Project:		morsix3330
* File:			disp3330.h
* Date:			20.12.2007
* Author:		Philipp Burch
* E-Mail:		philipp_burch@gmx.ch
* Description:	Header file for dispio.c.
******************************************************************************/

#ifndef __DISPIO_H__
#define __DISPIO_H__

#include <stdint.h>
#include <init.h>
#include <main.h>

typedef enum {
	COPY = 0,
	AND,
	OR,
	XOR,
	CLEAR
} draw_mode_t;

typedef struct {
	uint8_t x;
	uint8_t y;
} point_t;

//0 = Do not use cache, 1 = use cache
#define DISP_USE_CACHE	1
//0 = Display is not readable, 1 = Display can be read
#define DISP_CAN_READ	0
//0 = Horizontal alignment, 1 = Vertical alignment
#define DISP_CACHE_ALGN	1

#define DISP_TAB_WIDTH	8
#define DISP_LIN_HEIGHT	9

#define DISP_WIDTH		84
#define DISP_HEIGHT		48

/*
#define RPO_DISP_DC		PINC
#define PIN_DISP_DC		PC7
#define RPO_DISP_RES	PINC
#define PIN_DISP_RES	PC6
#define RPO_DISP_CS		PINC
#define PIN_DISP_CS		PC5
*/

#define DISP_SELECT		(RPO_DISP_CS &= ~_BV(PIN_DISP_CS))
#define DISP_RELEASE	(RPO_DISP_CS |= _BV(PIN_DISP_CS))
#define DISP_DC_CMD		(RPO_DISP_DC &= ~_BV(PIN_DISP_DC))
#define DISP_DC_DATA	(RPO_DISP_DC |= _BV(PIN_DISP_DC))


void Disp_Init();
void Disp_Clear();
void Disp_Control();
#if DISP_USE_CACHE == 1 || DISP_CAN_READ == 1
	void Disp_SetPx(const uint8_t, const uint8_t);
	void Disp_ClrPx(const uint8_t, const uint8_t);
	void Disp_InvPx(const uint8_t, const uint8_t);
	bool Disp_GetPx(const uint8_t, const uint8_t);
	point_t Disp_Print(const uint8_t,
					   const uint8_t,
					   const uint8_t,
					   const uint8_t,
					   const uint8_t,
					   const uint8_t,
					   char *,
					   const draw_mode_t,
					   const bool,
					   const bool);
	void Disp_Box(const uint8_t,
				  const uint8_t,
				  const uint8_t,
				  const uint8_t,
				  const draw_mode_t,
				  const bool);
	void Disp_Line(const uint8_t,
				   const uint8_t,
				   const uint8_t,
				   const uint8_t,
				   const draw_mode_t);
#endif
#if DISP_USE_CACHE == 1
	void Disp_Clear_Cache();
	void Disp_Refresh();
#endif
void Disp_Contrast(const uint8_t);

#endif //__DISPIO_H__
