/******************************************************************************
Project:		TIRF
File:			debug.c
Author:			Philipp Burch
Date:			04.04.2007
Description:	This file contains debug routines to send data over a software
				SPI (DEBUG0 = CLK and DEBUG1 = DATA).
******************************************************************************/

#include <stdint.h>
#include <debug.h>
#include <init.h>
#include <avr/io.h>
#include <main.h>
#include <avr/pgmspace.h>
#include <stdlib.h>
#include <util/delay.h>

void debug_send(uint8_t data) {
	loop_until_bit_is_set(UCSR0A, UDRE0);
	UDR0 = data;
}

void debug_send_hex(long data) {
	debug_send('0');
	debug_send('x');
	char s[9];
	ltoa(data, s, 16);
	debug_send_text(s);
	debug_send(' ');
}

void debug_send_text(char text[]) {
	if (*text == 0) return;
	do {
		debug_send(*text);
	} while (*(++text));
}

void debug_send_text_P(prog_char text[]) {
	uint8_t chr;
	while ((chr = pgm_read_byte(text++))) {
		debug_send(chr);
	}
}

void debug_send_text_len(char text[], uint8_t length) {
	uint8_t i;
	for (i = 0; i < length; i++) {
		debug_send(text[i]);
	}
}

void debug_send_var(char name[], long value) {
	debug_send_text(name);
	debug_send('=');
	debug_send_hex(value);
	debug_send('\n');
}

void debug_send_text_var(char name[], char value[], uint8_t len) {
	debug_send_text(name);
	debug_send('=');
	if (len) {
		debug_send_text_len(value, len);
	} else {
		debug_send_text(value);
	}
	debug_send('\n');
	_delay_ms(5);
}
