/******************************************************************************
* Project:		morsix3330
* File:			init.c
* Date:			09.12.2007
* Author:		Philipp Burch
* E-Mail:		philipp_burch@gmx.ch
* Description:	This file contains basic initializations such as defining of
*				IO-Pin directions.
******************************************************************************/

#include <init.h>
#include <stdint.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>


void init_ports() {
	GPIOR0 = 0;
	if (!GPIOR0) {
		//Avoid disabling JTAG while debugging
		_delay_ms(10);
		MCUCR |= _BV(JTD);
		MCUCR |= _BV(JTD);
	}

	PORTA = 0x3c;
	DDRA = 0x03;

	PORTB = 0x54;
	DDRB = 0xbb;

	PORTC = 0x21;
	DDRC = 0xff;

	PORTD = 0x01;
	DDRD = 0x72;
}

void init_clock() {
	//Decrease system clock to F_OSC / 8
	cli();
	CLKPR = _BV(CLKPCE);
	CLKPR = _BV(CLKPS1) | _BV(CLKPS0);
	sei();
}

void init_spi() {
	SPCR = _BV(SPE) | _BV(MSTR);
	SPSR = _BV(SPI2X);
}

void init_usart() {
	UCSR0A = _BV(U2X0);
	UCSR0B = _BV(TXEN0);
	UCSR0C = _BV(UCSZ01) | _BV(UCSZ00);
	UBRR0 = 12;		//19'200Baud
}

void init_sound() {
	TCCR1A = _BV(COM1A0) | _BV(COM1B0);
	TCCR1B = _BV(WGM12) | _BV(CS10);
	OCR1A = OCR1B = F_CPU / 900 / 2;
}
